#
# spec file for package hwsd
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#

%define old_soname 1
%define soname 2
%if 0%{?suse_version} == 1320
%bcond_without qt4
%endif
Name:           hwsd
Version:        1.1.1
Release:        pm152.5.13
Summary:        Local and remote GPU discovery
License:        GPL-3.0 and LGPL-2.1
Group:          System/Daemons
Url:            http://www.equalizergraphics.com/
Source0:        https://github.com/Eyescale/hwsd/archive/1.1.1.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/Eyescale/CMake/archive/master.tar.gz#/CMake-common_git20150515.tar.gz
# PATCH-FIX-UPSTREAM libdir.patch avvissu@yandex.ru -- Patch to fix the libdir on 64-bit architecture
Patch0:         hwsd-1.1.1_libdir.patch
# PATCH-FIX-OPENSUSE include.patch avvissu@yandex.ru -- Remove Buildyard project
Patch1:         hwsd-1.1.1_include.patch
# PATCH-FIX-UPSTREAM doxygen.patch avvissu@yandex.ru -- Fix build error: need administrative privileges
Patch2:         CMake_doxygen.patch
# PATCH-FIX-UPSTREAM avahi.patch -- Fix hw_sd build when Lunchbox uses Avahi implementation of Zerconf
# https://github.com/Eyescale/hwsd/commit/0f120821a044141c4c30c13618a91967cbf4e109
Patch3:         hwsd-1.1.1_avahi.patch
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  pkgconfig(Lunchbox)
##########Recommends##########
%if %{with qt4}
BuildRequires:  pkgconfig(QtCore) >= 4.6.0
BuildRequires:  pkgconfig(QtNetwork)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(x11)
%endif

%description
HW-SD is a library and daemon for the discovery and announcement of hardware
resources using ZeroConf. It enables auto-configuration of ad-hoc GPU clusters
and multi-GPU machines.

%package -n     lib%{name}%{soname}
Summary:        Local and remote GPU discovery: HW-SD libraries
License:        GPL-3.0 and LGPL-2.1
Group:          System/Libraries
Provides:       lib%{name}%{old_soname} = %{version}
Obsoletes:      lib%{name}%{old_soname} < %{version}

%description -n lib%{name}%{soname}
HW-SD is a library and daemon for the discovery and announcement of hardware
resources using ZeroConf. It enables auto-configuration of ad-hoc GPU clusters
and multi-GPU machines.

%package 		devel
Summary:        Development files for %{name}
License:        GPL-3.0 and LGPL-2.1
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{soname} = %{version}-%{release}
Requires:       pkgconfig(Lunchbox)

%description 	devel
Local and remote GPU discovery.
...
This package contains header files and libraries needed to develop
application that use %{name}.

%package 		doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description 	doc
Local and remote GPU discovery.
...
API Documentation for %{name}.

%prep
%setup -q -a1
mv CMake-common* CMake/common
%patch0 -p1
%patch1 -p1
%patch3 -p1
pushd CMake/common
%patch2 -p1
popd

# Do not compile in DATE and TIME
grep -rl 'HTML_TIMESTAMP' . | \
	xargs --no-run-if-empty --verbose \
	sed -i '/^HTML_TIMESTAMP/s/YES/NO/'
# Add link to library
%if 0%{?suse_version} > 1320
sed -i '/HWSD_LINK_LIBRARIES/s/\({QT_LIBRARIES}\)/\1 -lQtCore/' \
hwsd/CMakeLists.txt
%endif

%build
%cmake \
    -DCMAKE_BUILD_TYPE=Release \
    -DCMAKE_SKIP_RPATH:BOOL=OFF

make %{?_smp_mflags}
make %{?_smp_mflags} doxygen

%install
%make_install -C build

mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}{%{_datadir}/%{name}/doc,%{_docdir}/%{name}}

%fdupes -s %{buildroot}%{_docdir}

%check
sed -i '/ctest/s|\(bin/ctest\)|\1 -V|' build/Makefile
make test -C build

%post -n lib%{name}%{soname} -p /sbin/ldconfig

%postun -n lib%{name}%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_docdir}/%{name}
%{_bindir}/hw_sd
%{_bindir}/hw_sd_list
%exclude %{_docdir}/%{name}/API

%files -n lib%{name}%{soname}
%defattr(-,root,root)
%{_libdir}/lib%{name}*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_libdir}/lib%{name}*.so
%{_libdir}/pkgconfig/%{name}*.pc
%{_datadir}/%{name}

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}/API

%changelog
* Wed Nov  4 2015 avvissu@yandex.ru
- Don't use qt4 on openSUSE > 13.2
* Sun May 31 2015 avvissu@yandex.ru
- Fix conflicts files from package:
  * add old_soname from old package
* Sat May 16 2015 avvissu@yandex.ru
- Update to 1.1.1
- Add source package CMake-common (Common CMake modules)
- Drop old patches:
  * date-and-time.diff
  * DoxygenRule.diff
  * fix-64bit.diff
- Add new patches:
  * CMake_doxygen.patch
  * hwsd-1.1.1_avahi.patch
  * hwsd-1.1.1_include.patch
  * hwsd-1.1.1_libdir.patch
- Add recommended packages to build with optional packages
- Use pkgconfig in package names
- Add link to library on openSUSE > 13.2
- Use %%%%cmake macro instead of cmake
- Spec file
* Fri Mar 14 2014 avvissu@yandex.ru
- [Fixed] RPMlint W: Your file uses  __DATE and __TIME__ this
  causes the package to rebuild when not needed
* Wed Dec 25 2013 avvissu@yandex.ru
- add gpu_dns_sd: Remote ZeroConf (Bonjour) discovery for GPUs
  announced by the daemon
- add net_dns_sd: Remote ZeroConf (Bonjour) discovery for network
  interfaces announced by the daemon
* Fri Dec 20 2013 avvissu@yandex.ru
- Initial release 1.0.0
